@@ -1,12 +1,13 @@
 // biome-ignore assist/source/organizeImports: import mocks first
-import {afterAll, afterEach, beforeAll, beforeEach, describe, expect, it} from "vitest";
+import {afterAll, afterEach, beforeAll, beforeEach, describe, expect, it, vi} from "vitest";
 import * as data from "./mocks/data";
 
-import {existsSync, readFileSync, rmSync} from "node:fs";
+import {existsSync, readFileSync, rmSync, writeFileSync} from "node:fs";
 import objectAssignDeep from "object-assign-deep";
 import mockedData from "../lib/util/data";
 import * as settings from "../lib/util/settings";
 import * as settingsMigration from "../lib/util/settingsMigration";
+import path from "node:path";
 
 describe("Settings Migration", () => {
     beforeAll(() => {});
@@ -916,4 +917,79 @@ describe("Settings Migration", () => {
             expect(migrationNotesContent).toContain("[SPECIAL] Device icons are now saved as images.");
         });
     });
+
+    describe("Migrates v4 to v5", () => {
+        const BASE_CONFIG = {
+            version: 4,
+            mqtt: {
+                server: "mqtt://localhost",
+            },
+        };
+        const DEFAULT_STATE: Record<string, unknown> = {
+            "0x000b57fffec6a5b2": {
+                state: "ON",
+                brightness: 50,
+                color_temp: 370,
+                linkquality: 99,
+            },
+            "0x0017880104e45517": {
+                brightness: 255,
+                update: {state: "idle"},
+            },
+            1: {
+                state: "ON",
+                update: {state: "available", installed_version: 1, latest_version: 2},
+            },
+        };
+
+        beforeEach(() => {
+            settings.testing.CURRENT_VERSION = 5; // stop update after this version
+            data.writeDefaultConfiguration(BASE_CONFIG);
+            data.writeDefaultState(DEFAULT_STATE);
+            settings.reRead();
+        });
+
+        it("Update", () => {
+            // @ts-expect-error workaround
+            const beforeSettings = objectAssignDeep.noMutate({}, settings.getPersistedSettings());
+            // @ts-expect-error workaround
+            const afterSettings = objectAssignDeep.noMutate({}, settings.getPersistedSettings());
+            afterSettings.version = 5;
+
+            expect(settings.getPersistedSettings()).toStrictEqual(beforeSettings);
+            expect(data.readState()).toStrictEqual(DEFAULT_STATE);
+
+            settingsMigration.migrateIfNecessary();
+
+            const migratedSettings = settings.getPersistedSettings();
+            expect(migratedSettings).toStrictEqual(afterSettings);
+
+            // @ts-expect-error workaround
+            const migratedState = objectAssignDeep.noMutate({}, DEFAULT_STATE);
+            delete (migratedState["0x0017880104e45517"] as Record<string, unknown>).update;
+            delete (migratedState[1] as Record<string, unknown>).update;
+
+            expect(data.readState()).toStrictEqual(migratedState);
+        });
+
+        it("handles errors gracefully", () => {
+            const consoleErrorSpy = vi.spyOn(console, "error");
+            writeFileSync(path.join(data.mockDir, "state.json"), "notjson", "utf8");
+
+            // @ts-expect-error workaround
+            const beforeSettings = objectAssignDeep.noMutate({}, settings.getPersistedSettings());
+            // @ts-expect-error workaround
+            const afterSettings = objectAssignDeep.noMutate({}, settings.getPersistedSettings());
+            afterSettings.version = 5;
+
+            expect(settings.getPersistedSettings()).toStrictEqual(beforeSettings);
+
+            settingsMigration.migrateIfNecessary();
+
+            const migratedSettings = settings.getPersistedSettings();
+            expect(migratedSettings).toStrictEqual(afterSettings);
+            expect(consoleErrorSpy).toHaveBeenCalledWith(expect.stringContaining("Failed to write state"));
+            expect(consoleErrorSpy).toHaveBeenCalledWith(expect.stringContaining("is not valid JSON"));
+        });
+    });
 });
